@@ -2,13 +2,10 @@
 **  Copyright (c) 2005-2008 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 **
-**  Copyright (c) 2009, 2011, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2009, 2011, 2012, The Trusted Domain Project.
+**    All rights reserved.
 */
 
-#ifndef lint
-static char t_test47_c_id[] = "@(#)$Id: t-test47.c,v 1.2 2009/12/08 19:14:27 cm-msk Exp $";
-#endif /* !lint */
-
 #include "build-config.h"
 
 /* system includes */
@@ -27,7 +24,7 @@ static char t_test47_c_id[] = "@(#)$Id: t-test47.c,v 1.2 2009/12/08 19:14:27 cm-
 
 #define	MAXHEADER	4096
 
-char *always_sign[] = 
+char *over_sign[] = 
 {
 	"Cc",
 	NULL
@@ -94,8 +91,8 @@ main(int argc, char **argv)
 	(void) dkim_options(lib, DKIM_OP_SETOPT, DKIM_OPTS_FIXEDTIME,
 	                    &fixed_time, sizeof fixed_time);
 
-	(void) dkim_options(lib, DKIM_OP_SETOPT, DKIM_OPTS_ALWAYSHDRS,
-	                    &always_sign, sizeof (char **));
+	(void) dkim_options(lib, DKIM_OP_SETOPT, DKIM_OPTS_OVERSIGNHDRS,
+	                    &over_sign, sizeof (char **));
 
 	status = dkim_header(dkim, HEADER02, strlen(HEADER02));
 	assert(status == DKIM_STAT_OK);
