@@ -2,16 +2,12 @@
 **  Copyright (c) 2005, 2007, 2008 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 **
-**  Copyright (c) 2009-2011, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2009-2012, The Trusted Domain Project.  All rights reserved.
 */
 
 #ifndef _UTIL_H_
 #define _UTIL_H_
 
-#ifndef lint
-static char util_h_id[] = "@(#)$Id: util.h,v 1.5.10.1 2010/10/27 21:43:08 cm-msk Exp $";
-#endif /* !lint */
-
 #include "build-config.h"
 
 /* system includes */
@@ -37,6 +33,7 @@ extern void dkim_lowerhdr __P((u_char *));
 extern void dkim_min_timeval __P((struct timeval *, struct timeval *,
                                   struct timeval *, struct timeval **));
 extern int dkim_qp_decode __P((u_char *, u_char *, int));
+extern int dkim_qp_encode __P((u_char *, u_char *, int));
 
 #ifdef NEED_FAST_STRTOUL
 extern unsigned long dkim_strtoul __P((const char *str, char **endptr,
