@@ -1,13 +1,8 @@
 /*
-**  Copyright (c) 2010, 2011, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2010-2012, The Trusted Domain Project.  All rights reserved.
 **
-**  $Id: opendkim-genzone.c,v 1.12.10.1 2010/10/27 21:43:09 cm-msk Exp $
 */
 
-#ifndef lint
-static char opendkim_genzone_c_id[] = "$Id: opendkim-genzone.c,v 1.12.10.1 2010/10/27 21:43:09 cm-msk Exp $";
-#endif /* !lint */
-
 #include "build-config.h"
 
 /* system includes */
@@ -58,7 +53,7 @@ static char opendkim_genzone_c_id[] = "$Id: opendkim-genzone.c,v 1.12.10.1 2010/
 
 /* definitions */
 #define	BUFRSZ		1024
-#define	CMDLINEOPTS	"C:d:DE:o:N:r:R:St:T:vx:"
+#define	CMDLINEOPTS	"C:d:DE:o:N:r:R:St:T:uvx:"
 #define	DEFCONFFILE	CONFIG_BASE "/opendkim.conf"
 #define	DEFEXPIRE	604800
 #define	DEFREFRESH	10800
@@ -207,6 +202,7 @@ usage(void)
 	                "\t-S          \twrite an SOA record\n"
 	                "\t-t secs     \tuse specified per-record TTL\n"
 	                "\t-T secs     \tuse specified default TTL in SOA\n"
+	                "\t-u          \tproduce output suitable for use by \"nsupdate\"\n"
 	                "\t-v          \tverbose output\n"
 	                "\t-x file     \tconfiguration file\n",
 		progname, progname);
@@ -228,6 +224,7 @@ int
 main(int argc, char **argv)
 {
 	_Bool seenlf;
+	_Bool nsupdate = FALSE;
 	_Bool suffix = FALSE;
 	_Bool writesoa = FALSE;
 	int c;
@@ -329,6 +326,10 @@ main(int argc, char **argv)
 			}
 			break;
 
+		  case 'S':
+			writesoa = TRUE;
+			break;
+
 		  case 't':
 			ttl = strtol(optarg, &p, 10);
 			if (*p != '\0' || ttl < 0)
@@ -350,8 +351,8 @@ main(int argc, char **argv)
 			}
 			break;
 
-		  case 'S':
-			writesoa = TRUE;
+		  case 'u':
+			nsupdate = TRUE;
 			break;
 
 		  case 'v':
@@ -532,12 +533,16 @@ main(int argc, char **argv)
 
 	(void) time(&now);
 
-	fprintf(out, "; DKIM public key zone data\n");
-	if (onlydomain != NULL)
-		fprintf(out, "; for %s\n", onlydomain);
-	fprintf(out, "; auto-generated by %s at %s\n", progname, ctime(&now));
+	if (!nsupdate)
+	{
+		fprintf(out, "; DKIM public key zone data\n");
+		if (onlydomain != NULL)
+			fprintf(out, "; for %s\n", onlydomain);
+		fprintf(out, "; auto-generated by %s at %s\n", progname,
+		        ctime(&now));
+	}
 
-	if (writesoa)
+	if (writesoa && !nsupdate)
 	{
 		struct tm *tm;
 
@@ -580,7 +585,7 @@ main(int argc, char **argv)
 		        refresh, retry, expire, defttl);
 	}
 
-	if (nameservers != NULL)
+	if (nameservers != NULL && !nsupdate)
 	{
 		for (c = 0; c < nscount; c++)
 			fprintf(out, "\tIN\tNS\t%s\n", nslist[c]);
@@ -588,6 +593,9 @@ main(int argc, char **argv)
 		fprintf(out, "\n");
 	}
 
+	if (nsupdate)
+		fprintf(out, "server %s\n", nslist[0]);
+
 	dbd[0].dbdata_buffer = domain;
 	dbd[1].dbdata_buffer = selector;
 	dbd[2].dbdata_buffer = keydata;
@@ -818,22 +826,37 @@ main(int argc, char **argv)
 #endif /* USE_GNUTLS */
 
 		/* write the record */
-		if (ttl == -1)
+		if (nsupdate)
 		{
+			fprintf(out, "zone %s\n", domain);
+
 			snprintf(tmpbuf, sizeof tmpbuf,
-			         "%s%s\tIN\tTXT\t( \"v=DKIM1; k=rsa; p=",
-			         selector, suffix ? DKIMZONE : "");
+			         "update add %s%s %d TXT \"",
+			         selector, suffix ? DKIMZONE : "",
+			         ttl == -1 ? defttl : ttl);
 		}
 		else
 		{
-			snprintf(tmpbuf, sizeof tmpbuf,
-			         "%s%s\t%d\tIN\tTXT\t( \"v=DKIM1; k=rsa; p=",
-			         selector, suffix ? DKIMZONE : "", ttl);
+			if (ttl == -1)
+			{
+				snprintf(tmpbuf, sizeof tmpbuf,
+				         "%s%s\tIN\tTXT\t( \"v=DKIM1; k=rsa; p=",
+				         selector, suffix ? DKIMZONE : "");
+			}
+			else
+			{
+				snprintf(tmpbuf, sizeof tmpbuf,
+				         "%s%s\t%d\tIN\tTXT\t( \"v=DKIM1; k=rsa; p=",
+				         selector, suffix ? DKIMZONE : "", ttl);
+			}
 		}
 
 		fprintf(out, "%s", tmpbuf);
 
-		olen = strflen(tmpbuf);
+		if (nsupdate)
+			olen = 0;
+		else
+			olen = strflen(tmpbuf);
 
 		seenlf = FALSE;
 
@@ -891,18 +914,26 @@ main(int argc, char **argv)
 			}
 			else if (isascii(*p) && !isspace(*p))
 			{
+				if (olen >= MARGIN && !nsupdate)
+				{
+					fprintf(out, "\"\n\t\"");
+					olen = 9;
+				}
+				else if (olen >= 255 && nsupdate)
+				{
+					fprintf(out, "\" \"");
+					olen = 0;
+				}
+
 				(void) fputc(*p, out);
 				olen++;
 			}
-
-			if (olen >= MARGIN)
-			{
-				fprintf(out, "\"\n\t\"");
-				olen = 9;
-			}
 		}
 
-		fprintf(out, "\" )\n");
+		if (nsupdate)
+			fprintf(out, "\"\n");
+		else
+			fprintf(out, "\" )\n");
 
 		/* prepare for the next one */
 #ifdef USE_GNUTLS
@@ -920,6 +951,9 @@ main(int argc, char **argv)
 #endif /* ! USE_GNUTLS */
 	(void) dkimf_db_close(db);
 
+	if (nsupdate)
+		fprintf(out, "send\nanswer\n");
+
 	if (out != stdout)
 		fclose(out);
 
