@@ -1,12 +1,15 @@
-
--- Copyright (c) 2009-2012, The Trusted Domain Project.  All rights reserved.
+-- Copyright (c) 2009-2013, The Trusted Domain Project.  All rights reserved.
 
 -- simple/simple verify test using Lua features
 
 mt.echo("*** simple/simple verifying test using Lua features")
 
 -- setup
-sock = "unix:" .. mt.getcwd() .. "/t-lua-verify-tests.sock"
+if TESTSOCKET ~= nil then
+	sock = TESTSOCKET
+else
+	sock = "unix:" .. mt.getcwd() .. "/t-lua-verify-tests.sock"
+end
 binpath = mt.getcwd() .. "/.."
 if os.getenv("srcdir") ~= nil then
 	mt.chdir(os.getenv("srcdir"))
@@ -17,7 +20,7 @@ mt.startfilter(binpath .. "/opendkim", "-x", "t-lua-verify-tests.conf",
                "-p", sock)
 
 -- try to connect to it
-conn = mt.connect(sock, 40, 0.05)
+conn = mt.connect(sock, 40, 0.25)
 if conn == nil then
 	error("mt.connect() failed")
 end
